@@ -9,6 +9,9 @@ from bip_utils.bip.bip32.bip32_ex import Bip32KeyError, Bip32PathError
 from bip_utils.bip.bip32.bip32_key_data import (
     Bip32ChainCode, Bip32Depth, Bip32FingerPrint, Bip32KeyIndex, Bip32KeyData
 )
+from bip_utils.bip.bip32.bip32_key_ser import (
+    Bip32PublicKeySerializer, Bip32PrivateKeySerializer, Bip32DeserializedKey, Bip32KeyDeserializer
+)
 from bip_utils.bip.bip32.bip32_key_net_ver import Bip32KeyNetVersions
 from bip_utils.bip.bip32.bip32_keys import Bip32PublicKey, Bip32PrivateKey
 from bip_utils.bip.bip32.bip32_path import Bip32PathParser, Bip32Path
