@@ -35,6 +35,7 @@ from bip_utils.bip.conf.common import (
     BipCoinConf, BipBitcoinCashConf, BipLitecoinConf, HARDENED_DEF_PATH, NOT_HARDENED_DEF_PATH
 )
 from bip_utils.coin_conf import CoinsConf
+from bip_utils.slip.slip44 import Slip44
 
 
 # Bitcoin key net version for main net (same as BIP32)
@@ -49,7 +50,7 @@ class Bip44Conf:
     # Configuration for Akash Network
     AkashNetwork: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.AkashNetwork.CoinNames(),
-        coin_idx=118,
+        coin_idx=Slip44.ATOM,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -64,7 +65,7 @@ class Bip44Conf:
     # Configuration for Algorand
     Algorand: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Algorand.CoinNames(),
-        coin_idx=283,
+        coin_idx=Slip44.ALGORAND,
         is_testnet=False,
         def_path=HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -77,7 +78,7 @@ class Bip44Conf:
     # Configuration for Avax C-Chain
     AvaxCChain: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.AvaxCChain.CoinNames(),
-        coin_idx=60,
+        coin_idx=Slip44.ETHEREUM,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -89,7 +90,7 @@ class Bip44Conf:
     # Configuration for Avax P-Chain
     AvaxPChain: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.AvaxPChain.CoinNames(),
-        coin_idx=9000,
+        coin_idx=Slip44.AVALANCHE,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -101,7 +102,7 @@ class Bip44Conf:
     # Configuration for Avax X-Chain
     AvaxXChain: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.AvaxXChain.CoinNames(),
-        coin_idx=9000,
+        coin_idx=Slip44.AVALANCHE,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -111,10 +112,25 @@ class Bip44Conf:
         addr_params={},
     )
 
+    # Configuration for Axelar
+    Axelar: BipCoinConf = BipCoinConf(
+        coin_names=CoinsConf.Axelar.CoinNames(),
+        coin_idx=Slip44.ATOM,
+        is_testnet=False,
+        def_path=NOT_HARDENED_DEF_PATH,
+        key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
+        wif_net_ver=None,
+        bip32_cls=Bip32Secp256k1,
+        addr_cls=AtomAddrEncoder,
+        addr_params={
+            "hrp": CoinsConf.Axelar.Params("addr_hrp"),
+        },
+    )
+
     # Configuration for Band Protocol
     BandProtocol: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.BandProtocol.CoinNames(),
-        coin_idx=494,
+        coin_idx=Slip44.BAND_PROTOCOL,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -129,7 +145,7 @@ class Bip44Conf:
     # Configuration for Binance Chain
     BinanceChain: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.BinanceChain.CoinNames(),
-        coin_idx=714,
+        coin_idx=Slip44.BINANCE_CHAIN,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -143,7 +159,7 @@ class Bip44Conf:
     # Configuration for Binance Smart Chain
     BinanceSmartChain: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.BinanceSmartChain.CoinNames(),
-        coin_idx=60,
+        coin_idx=Slip44.ETHEREUM,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -156,7 +172,7 @@ class Bip44Conf:
     # Configuration for Bitcoin main net
     BitcoinMainNet: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.BitcoinMainNet.CoinNames(),
-        coin_idx=0,
+        coin_idx=Slip44.BITCOIN,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -170,7 +186,7 @@ class Bip44Conf:
     # Configuration for Bitcoin test net
     BitcoinTestNet: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.BitcoinTestNet.CoinNames(),
-        coin_idx=1,
+        coin_idx=Slip44.TESTNET,
         is_testnet=True,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
@@ -185,7 +201,7 @@ class Bip44Conf:
     # Configuration for Bitcoin Cash main net
     BitcoinCashMainNet: BipBitcoinCashConf = BipBitcoinCashConf(
         coin_names=CoinsConf.BitcoinCashMainNet.CoinNames(),
-        coin_idx=145,
+        coin_idx=Slip44.BITCOIN_CASH,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -206,7 +222,7 @@ class Bip44Conf:
     # Configuration for Bitcoin Cash test net
     BitcoinCashTestNet: BipBitcoinCashConf = BipBitcoinCashConf(
         coin_names=CoinsConf.BitcoinCashTestNet.CoinNames(),
-        coin_idx=1,
+        coin_idx=Slip44.TESTNET,
         is_testnet=True,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
@@ -228,7 +244,7 @@ class Bip44Conf:
     # Configuration for Bitcoin Cash Simple Ledger Protocol main net
     BitcoinCashSlpMainNet: BipBitcoinCashConf = BipBitcoinCashConf(
         coin_names=CoinsConf.BitcoinCashSlpMainNet.CoinNames(),
-        coin_idx=145,
+        coin_idx=Slip44.BITCOIN_CASH,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -249,7 +265,7 @@ class Bip44Conf:
     # Configuration for Bitcoin Cash Simple Ledger Protocol test net
     BitcoinCashSlpTestNet: BipBitcoinCashConf = BipBitcoinCashConf(
         coin_names=CoinsConf.BitcoinCashSlpTestNet.CoinNames(),
-        coin_idx=1,
+        coin_idx=Slip44.TESTNET,
         is_testnet=True,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
@@ -271,7 +287,7 @@ class Bip44Conf:
     # Configuration for BitcoinSV main net
     BitcoinSvMainNet: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.BitcoinSvMainNet.CoinNames(),
-        coin_idx=236,
+        coin_idx=Slip44.BITCOIN_SV,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -285,7 +301,7 @@ class Bip44Conf:
     # Configuration for BitcoinSV test net
     BitcoinSvTestNet: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.BitcoinSvTestNet.CoinNames(),
-        coin_idx=1,
+        coin_idx=Slip44.TESTNET,
         is_testnet=True,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
@@ -300,7 +316,7 @@ class Bip44Conf:
     # Configuration for Celo
     Celo: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Celo.CoinNames(),
-        coin_idx=52752,
+        coin_idx=Slip44.CELO,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -313,7 +329,7 @@ class Bip44Conf:
     # Configuration for Certik
     Certik: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Certik.CoinNames(),
-        coin_idx=118,
+        coin_idx=Slip44.ATOM,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -328,7 +344,7 @@ class Bip44Conf:
     # Configuration for Chihuahua
     Chihuahua: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Chihuahua.CoinNames(),
-        coin_idx=118,
+        coin_idx=Slip44.ATOM,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -343,7 +359,7 @@ class Bip44Conf:
     # Configuration for Cosmos
     Cosmos: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Cosmos.CoinNames(),
-        coin_idx=118,
+        coin_idx=Slip44.ATOM,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -358,7 +374,7 @@ class Bip44Conf:
     # Configuration for Dash main net
     DashMainNet: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.DashMainNet.CoinNames(),
-        coin_idx=5,
+        coin_idx=Slip44.DASH,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -372,7 +388,7 @@ class Bip44Conf:
     # Configuration for Dash test net
     DashTestNet: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.DashTestNet.CoinNames(),
-        coin_idx=1,
+        coin_idx=Slip44.TESTNET,
         is_testnet=True,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
@@ -387,7 +403,7 @@ class Bip44Conf:
     # Configuration for Dogecoin main net
     DogecoinMainNet: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.DogecoinMainNet.CoinNames(),
-        coin_idx=3,
+        coin_idx=Slip44.DOGECOIN,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=Bip32KeyNetVersions(b"\x02\xfa\xca\xfd",
@@ -402,7 +418,7 @@ class Bip44Conf:
     # Configuration for Dogecoin test net
     DogecoinTestNet: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.DogecoinTestNet.CoinNames(),
-        coin_idx=1,
+        coin_idx=Slip44.TESTNET,
         is_testnet=True,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=Bip32KeyNetVersions(b"\x04\x32\xa9\xa8",
@@ -418,7 +434,7 @@ class Bip44Conf:
     # Configuration for eCash main net
     EcashMainNet: BipBitcoinCashConf = BipBitcoinCashConf(
         coin_names=CoinsConf.EcashMainNet.CoinNames(),
-        coin_idx=145,
+        coin_idx=Slip44.BITCOIN_CASH,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -439,7 +455,7 @@ class Bip44Conf:
     # Configuration for eCash test net
     EcashTestNet: BipBitcoinCashConf = BipBitcoinCashConf(
         coin_names=CoinsConf.EcashTestNet.CoinNames(),
-        coin_idx=1,
+        coin_idx=Slip44.TESTNET,
         is_testnet=True,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
@@ -461,7 +477,7 @@ class Bip44Conf:
     # Configuration for Elrond
     Elrond: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Elrond.CoinNames(),
-        coin_idx=508,
+        coin_idx=Slip44.ELROND,
         is_testnet=False,
         def_path=HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -474,7 +490,7 @@ class Bip44Conf:
     # Configuration for Eos
     Eos: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Eos.CoinNames(),
-        coin_idx=194,
+        coin_idx=Slip44.EOS,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -487,7 +503,7 @@ class Bip44Conf:
     # Configuration for Ethereum
     Ethereum: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Ethereum.CoinNames(),
-        coin_idx=60,
+        coin_idx=Slip44.ETHEREUM,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -499,7 +515,7 @@ class Bip44Conf:
     # Configuration for Ethereum Classic
     EthereumClassic: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.EthereumClassic.CoinNames(),
-        coin_idx=61,
+        coin_idx=Slip44.ETHEREUM_CLASSIC,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -512,7 +528,7 @@ class Bip44Conf:
     # Configuration for Fantom Opera
     FantomOpera: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.FantomOpera.CoinNames(),
-        coin_idx=60,
+        coin_idx=Slip44.ETHEREUM,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -525,7 +541,7 @@ class Bip44Conf:
     # Configuration for Filecoin
     Filecoin: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Filecoin.CoinNames(),
-        coin_idx=461,
+        coin_idx=Slip44.FILECOIN,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -538,7 +554,7 @@ class Bip44Conf:
     # Configuration for Harmony One (Metamask address)
     HarmonyOneMetamask: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.HarmonyOne.CoinNames(),
-        coin_idx=60,
+        coin_idx=Slip44.ETHEREUM,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -550,7 +566,7 @@ class Bip44Conf:
     # Configuration for Harmony One (Ethereum address)
     HarmonyOneEth: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.HarmonyOne.CoinNames(),
-        coin_idx=1023,
+        coin_idx=Slip44.HARMONY_ONE,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -562,7 +578,7 @@ class Bip44Conf:
     # Configuration for Harmony One (Atom address)
     HarmonyOneAtom: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.HarmonyOne.CoinNames(),
-        coin_idx=1023,
+        coin_idx=Slip44.HARMONY_ONE,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -575,7 +591,7 @@ class Bip44Conf:
     # Configuration for Huobi Chain
     HuobiChain: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.HuobiChain.CoinNames(),
-        coin_idx=60,
+        coin_idx=Slip44.ETHEREUM,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -588,7 +604,7 @@ class Bip44Conf:
     # Configuration for IRISnet
     IrisNet: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.IrisNet.CoinNames(),
-        coin_idx=118,
+        coin_idx=Slip44.ATOM,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -603,7 +619,7 @@ class Bip44Conf:
     # Configuration for Kava
     Kava: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Kava.CoinNames(),
-        coin_idx=494,
+        coin_idx=Slip44.KAVA,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -618,7 +634,7 @@ class Bip44Conf:
     # Configuration for Kusama (ed25519 SLIP-0010)
     KusamaEd25519Slip: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Kusama.CoinNames(),
-        coin_idx=354,
+        coin_idx=Slip44.KUSAMA,
         is_testnet=False,
         def_path=HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -633,7 +649,7 @@ class Bip44Conf:
     # Configuration for Litecoin main net
     LitecoinMainNet: BipLitecoinConf = BipLitecoinConf(
         coin_names=CoinsConf.LitecoinMainNet.CoinNames(),
-        coin_idx=2,
+        coin_idx=Slip44.LITECOIN,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -650,7 +666,7 @@ class Bip44Conf:
     # Configuration for Litecoin test net
     LitecoinTestNet: BipLitecoinConf = BipLitecoinConf(
         coin_names=CoinsConf.LitecoinTestNet.CoinNames(),
-        coin_idx=1,
+        coin_idx=Slip44.TESTNET,
         is_testnet=True,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=Bip32KeyNetVersions(b"\x04\x36\xf6\xe1",
@@ -669,7 +685,7 @@ class Bip44Conf:
     # Configuration for Monero (ed25519 SLIP-0010)
     MoneroEd25519Slip: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.MoneroMainNet.CoinNames(),
-        coin_idx=128,
+        coin_idx=Slip44.MONERO,
         is_testnet=False,
         def_path=HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -682,7 +698,7 @@ class Bip44Conf:
     # Configuration for Monero (secp256k1)
     MoneroSecp256k1: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.MoneroMainNet.CoinNames(),
-        coin_idx=128,
+        coin_idx=Slip44.MONERO,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -695,7 +711,7 @@ class Bip44Conf:
     # Configuration for Nano
     Nano: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Nano.CoinNames(),
-        coin_idx=165,
+        coin_idx=Slip44.NANO,
         is_testnet=False,
         def_path="0'",
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -708,7 +724,7 @@ class Bip44Conf:
     # Configuration for Near Protocol
     NearProtocol: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.NearProtocol.CoinNames(),
-        coin_idx=397,
+        coin_idx=Slip44.NEAR_PROTOCOL,
         is_testnet=False,
         def_path="0'",
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -721,7 +737,7 @@ class Bip44Conf:
     # Configuration for Neo
     Neo: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Neo.CoinNames(),
-        coin_idx=888,
+        coin_idx=Slip44.NEO,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -736,7 +752,7 @@ class Bip44Conf:
     # Configuration for NG
     NineChroniclesGold: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.NineChroniclesGold.CoinNames(),
-        coin_idx=567,
+        coin_idx=Slip44.NINE_CHRONICLES,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -749,7 +765,7 @@ class Bip44Conf:
     # Configuration for OKEx Chain (Ethereum address)
     OkexChainEth: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.OkexChain.CoinNames(),
-        coin_idx=60,
+        coin_idx=Slip44.ETHEREUM,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -762,7 +778,7 @@ class Bip44Conf:
     # Configuration for OKEx Chain (Atom address)
     OkexChainAtom: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.OkexChain.CoinNames(),
-        coin_idx=60,
+        coin_idx=Slip44.ETHEREUM,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -775,7 +791,7 @@ class Bip44Conf:
     # Configuration for OKEx Chain (old Atom address)
     OkexChainAtomOld: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.OkexChain.CoinNames(),
-        coin_idx=996,
+        coin_idx=Slip44.OKEX_CHAIN,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -788,7 +804,7 @@ class Bip44Conf:
     # Configuration for Ontology
     Ontology: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Ontology.CoinNames(),
-        coin_idx=1024,
+        coin_idx=Slip44.ONTOLOGY,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -803,7 +819,7 @@ class Bip44Conf:
     # Configuration for Osmosis
     Osmosis: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Osmosis.CoinNames(),
-        coin_idx=118,
+        coin_idx=Slip44.ATOM,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -818,7 +834,7 @@ class Bip44Conf:
     # Configuration for Polkadot (ed25519 SLIP-0010)
     PolkadotEd25519Slip: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Polkadot.CoinNames(),
-        coin_idx=354,
+        coin_idx=Slip44.POLKADOT,
         is_testnet=False,
         def_path=HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -833,7 +849,7 @@ class Bip44Conf:
     # Configuration for Polygon
     Polygon: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Polygon.CoinNames(),
-        coin_idx=60,
+        coin_idx=Slip44.ETHEREUM,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -846,7 +862,7 @@ class Bip44Conf:
     # Configuration for Ripple
     Ripple: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Ripple.CoinNames(),
-        coin_idx=144,
+        coin_idx=Slip44.RIPPLE,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -859,7 +875,7 @@ class Bip44Conf:
     # Configuration for Secret Network (old path)
     SecretNetworkOld: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.SecretNetwork.CoinNames(),
-        coin_idx=118,
+        coin_idx=Slip44.ATOM,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -873,7 +889,7 @@ class Bip44Conf:
     # Configuration for Secret Network (new path)
     SecretNetworkNew: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.SecretNetwork.CoinNames(),
-        coin_idx=529,
+        coin_idx=Slip44.SECRET_NETWORK,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -888,7 +904,7 @@ class Bip44Conf:
     # Configuration for Solana
     Solana: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Solana.CoinNames(),
-        coin_idx=501,
+        coin_idx=Slip44.SOLANA,
         is_testnet=False,
         def_path="0'",
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -901,7 +917,7 @@ class Bip44Conf:
     # Configuration for Stellar
     Stellar: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Stellar.CoinNames(),
-        coin_idx=148,
+        coin_idx=Slip44.STELLAR,
         is_testnet=False,
         def_path="0'",
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -914,7 +930,7 @@ class Bip44Conf:
     # Configuration for Terra
     Terra: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Terra.CoinNames(),
-        coin_idx=330,
+        coin_idx=Slip44.TERRA,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -929,7 +945,7 @@ class Bip44Conf:
     # Configuration for Tezos
     Tezos: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Tezos.CoinNames(),
-        coin_idx=1729,
+        coin_idx=Slip44.TEZOS,
         is_testnet=False,
         def_path="0'/0'",
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -942,7 +958,7 @@ class Bip44Conf:
     # Configuration for Theta
     Theta: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Theta.CoinNames(),
-        coin_idx=500,
+        coin_idx=Slip44.THETA,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -955,7 +971,7 @@ class Bip44Conf:
     # Configuration for Tron
     Tron: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Tron.CoinNames(),
-        coin_idx=195,
+        coin_idx=Slip44.TRON,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -968,7 +984,7 @@ class Bip44Conf:
     # Configuration for VeChain
     VeChain: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.VeChain.CoinNames(),
-        coin_idx=818,
+        coin_idx=Slip44.VECHAIN,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -981,7 +997,7 @@ class Bip44Conf:
     # Configuration for Verge
     Verge: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Verge.CoinNames(),
-        coin_idx=77,
+        coin_idx=Slip44.VERGE,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -996,7 +1012,7 @@ class Bip44Conf:
     # Configuration for Zcash main net
     ZcashMainNet: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.ZcashMainNet.CoinNames(),
-        coin_idx=133,
+        coin_idx=Slip44.ZCASH,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
@@ -1010,7 +1026,7 @@ class Bip44Conf:
     # Configuration for Zcash test net
     ZcashTestNet: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.ZcashTestNet.CoinNames(),
-        coin_idx=1,
+        coin_idx=Slip44.TESTNET,
         is_testnet=True,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
@@ -1025,7 +1041,7 @@ class Bip44Conf:
     # Configuration for Zilliqa
     Zilliqa: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Zilliqa.CoinNames(),
-        coin_idx=313,
+        coin_idx=Slip44.ZILLIQA,
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
