@@ -1,4 +1,4 @@
-from bip_utils.bip.conf.common.bip_conf_const import *
+from bip_utils.bip.conf.common.bip_conf_const import HARDENED_DEF_PATH, NOT_HARDENED_DEF_PATH
 from bip_utils.bip.conf.common.bip_coins import BipCoins
 from bip_utils.bip.conf.common.bip_coin_conf import BipCoinConf
 from bip_utils.bip.conf.common.bip_bitcoin_cash_conf import BipBitcoinCashConf
