@@ -1,4 +1,4 @@
 from bip_utils.monero.conf.monero_coins import MoneroCoins
 from bip_utils.monero.conf.monero_coin_conf import MoneroCoinConf
-from bip_utils.monero.conf.monero_conf import *
+from bip_utils.monero.conf.monero_conf import MoneroConf
 from bip_utils.monero.conf.monero_conf_getter import MoneroConfGetter
