@@ -1,8 +1,10 @@
 from bip_utils.utils.misc.aes_ecb import AesEcbDecrypter, AesEcbEncrypter
 from bip_utils.utils.misc.algo import AlgoUtils
+from bip_utils.utils.misc.base32 import Base32Decoder, Base32Encoder
 from bip_utils.utils.misc.bit import BitUtils
 from bip_utils.utils.misc.bytes import BytesUtils
 from bip_utils.utils.misc.crypto import CryptoUtils
 from bip_utils.utils.misc.data_bytes import DataBytes
 from bip_utils.utils.misc.integer import IntegerUtils
+from bip_utils.utils.misc.sha256 import Sha256
 from bip_utils.utils.misc.string import StringUtils
