@@ -4,6 +4,7 @@ from bip_utils.utils.mnemonic.mnemonic import MnemonicLanguages, Mnemonic
 from bip_utils.utils.mnemonic.mnemonic_decoder_base import MnemonicDecoderBase
 from bip_utils.utils.mnemonic.mnemonic_encoder_base import MnemonicEncoderBase
 from bip_utils.utils.mnemonic.mnemonic_utils import (
-    MnemonicWordsList, MnemonicWordsListFileReader, MnemonicWordsListGetterBase, MnemonicWordsListFinderBase
+    MnemonicUtils, MnemonicWordsList, MnemonicWordsListFileReader,
+    MnemonicWordsListGetterBase, MnemonicWordsListFinderBase
 )
 from bip_utils.utils.mnemonic.mnemonic_validator import MnemonicValidator
